@@ -154,6 +154,45 @@ REGEX_ORDERED_LIST = re.compile(r"""
             # times as possible.
     \s*     # Match between 0 and ∞ whitespaces.""", re.VERBOSE)
 
+REGEX_QUICK_EMAIL = re.compile(r"""
+    <               # Match "<" once.
+    (               # CAPTURE GROUP (1) | Open capture group.
+        [\w\d_.+-]+ # Match either a word character, a digit, "_", ".", "+", or
+                    # "-", between 1 and ∞ times.
+        @           # Match "@" once.
+        [\w\d-]+    # Match either a word character, a digit, or "-", between 1
+                    # and ∞ times.
+        \.          # Match "." once.
+        [\w\d.-]+   # Match either a word character, a digit, ".", or "-",
+                    # between 1 and ∞ times.
+    )               # CAPTURE GROUP (1) | Close and match capture group.
+    >               # Match ">" once.""", re.VERBOSE)
+
+REGEX_QUICK_LINK = re.compile(r"""
+    <                   # Match "<" once.
+    (                   # CAPTURE GROUP (1) | Open capture group.
+        https?          # Match either "http" or "https".
+        ://             # Match "://" once.
+        (?:             # Open non-capturing group.
+            -           # Match "-" once.
+            \.          # Match "." once.
+        )?              # Close non-capturing group and match it either 0 or 1
+                        # times.
+        (?:             # Open non-capturing group.
+            [^\s/?.#-]+ # Match any character that is not a whitespace, "/",
+                        # "?", ".", "#", or "-", between 1 and ∞ times.
+            \.?         # Match ".", either 0 or 1 times.
+        )+              # Close non-capturing group and match it between 1 and
+                        # ∞ times.
+        (?:             # Open non-capturing group.
+            /           # Match "/" once.
+            [^\s]*      # Match any character that is not a whitespace, between
+                        # 0 and ∞ times.
+        )?              # Close non-capturing group and match it either 0 or 1
+                        # times.
+    )                   # CAPTURE GROUP (1) | Close and match capture group.
+    >                   # Match ">" once.""", re.VERBOSE)
+
 REGEX_UNORDERED_LIST = re.compile(r"""
     (\s+)?  # CAPTURE GROUP (1) | Match between 1 and ∞ whitespaces, as many
             # times as possible, as either one or zero matches.
@@ -225,7 +264,6 @@ def check_paragraph(line):
     return True
 
 
-
 def convert_nested_tag(line, cur_tag, open_tags):
     """
     Convert one or more nested tags in a line.
@@ -462,6 +500,19 @@ def add_inline_tags(line):
             f'<a href="{url}"'
             + (f' title="{title}"' if title else '')
             + f'>{alt_text}</a>', line)
+
+    # Add quick email links.
+    if REGEX_QUICK_EMAIL.search(line):
+        match = REGEX_QUICK_EMAIL.search(line)
+        address = match.group(1)
+        line = REGEX_QUICK_EMAIL.sub(
+            f'<a href="mailto:{address}">{address}</a>', line)
+
+    # Add quick links.
+    if REGEX_QUICK_LINK.search(line):
+        match = REGEX_QUICK_LINK.search(line)
+        address = match.group(1)
+        line = REGEX_QUICK_LINK.sub(f'<a href="{address}">{address}</a>', line)
     return line
 
 
